@@ -1,4 +1,4 @@
-import time, pyperclip, os, darkdetect, threading, winshell
+import time, pyperclip, os, darkdetect, threading, base64, winshell
 from kivy import Config
 from kivy.uix.boxlayout import BoxLayout
 from kivymd.uix.button import MDFlatButton
@@ -482,9 +482,9 @@ Screen:
         except Exception as e:
             print(e)
 
-    def create_shortcut(self, source=__file__, target=None, name=None, only_exe=True):
+    def create_shortcut(self, source=__file__, target=None, name=None, only_exe=False):
 
-        if not only_exe and source.endswith('.exe'):
+        if only_exe and not source.endswith('.exe'):
             return 'Source file is not exe'
 
         if not target:
@@ -493,15 +493,50 @@ Screen:
         if not name:
             name = self.app_name
 
-        path = rf"{target}\{name}.lnk"
-        work_dir = os.path.dirname(source)
+        try:
+            path = rf"{target}\{name}.lnk"
+            work_dir = os.path.dirname(source)
 
-        shell = Dispatch('WScript.Shell')
-        shortcut = shell.CreateShortCut(path)
-        shortcut.Targetpath = source
-        shortcut.WorkingDirectory = work_dir
-        shortcut.save()
+            shell = Dispatch('WScript.Shell')
+            shortcut = shell.CreateShortCut(path)
+            shortcut.Targetpath = source
+            shortcut.WorkingDirectory = work_dir
+            shortcut.save()
+            return 'Successfully created shortcut'
+
+        except Exception as e:
+            print(e)
+            return e
 
     @staticmethod
     def get_shell_startup():
         return os.path.join(os.getenv("appdata"), "Microsoft", "Windows", "Start Menu", "Programs", "Startup")
+
+    @thread
+    def writeBase64(self, file, name=None):
+        if name is None:
+            name = os.path.basename(file).split('.')[0]
+
+        with open(file, 'rb') as b:
+            with open('bases.py', 'a') as f:
+                f.write(f'\n\n{name} = ["{base64.b64encode(b.read()).decode()}", "{os.path.basename(file)}"]')
+
+
+    def getBase64(self, file, name=None):
+
+        if name is None:
+            name = os.path.basename(file).split('.')[0]
+
+        try:
+            import bases
+
+        except ImportError:
+            return '"bases" file is not exist'
+
+        base, full_name = eval(f'bases.{name}')
+
+        with open(self.appdata_path + '/' + full_name, 'wb') as f:
+            f.write(base64.b64encode(base.encode()))
+
+
+
